@@ -2,6 +2,7 @@ from .calculateMetrics import *
 import seaborn as sns
 from .loadfile import *
 import matplotlib.pyplot as plt
+from statsmodels.sandbox.stats.multicomp import multipletests
 
 def readIF(parameter,chr,normIF=True,custom_name="InteractionFrequency"):
     all = pd.read_csv(parameter,sep="\t",header=None)
@@ -170,7 +171,7 @@ class repQC:
     def anova_like(self,start,end):
         sbin = start//self.res
         ebin = end//self.res
-        df = self.score.iloc[sbin:ebin,:].T
+        df = self.score.iloc[sbin:ebin,3:].T
 
         nLoci = df.shape[1]
         nScore = df.shape[0]
@@ -182,7 +183,9 @@ class repQC:
             pvalue = stats.f_oneway(*df_ilist)[1]
             arrays[i] = pvalue
 
-        return(arrays)
+        qvalue = np.zeros(nLoci)*np.NaN
+        qvalue[~np.isnan(arrays)] = multipletests(arrays[~np.isnan(arrays)], method='fdr_bh')[1]
+        return(arrays,qvalue)
 
         #from statsmodels.sandbox.stats.multicomp import multipletests
         #qvalue=multipletests(arrays, method='fdr_bh')
