@@ -173,7 +173,7 @@ def CLI():
     parser_two.add_argument("-d","--draw",action='store_true',help="Plot figure for candidate region",default=False)
     parser_two.add_argument('-s','--start',type=int,help="Start sites for plotting",default=0)
     parser_two.add_argument('-e','--end',type=int,help="End sites for plotting",default=0)
-    parser_two.add_argument('--datatype',type=str,help="matrix or rawhic",default="matrix")
+    parser_two.add_argument('--datatype',type=str,help="Type of input data: [matrix(default),rawhic,cool].",default="matrix")
     parser_two.add_argument('--gt',type=str,help="genome table file",default="")
     parser_two.add_argument('--prefix',type=str,help="${prefix}chr1.matrix.gz",default="observed.KR.")
     parser_two.add_argument('--maxchr',type=int,help="Maximum index of chromosome (human genome is 22,i.e.)",default=None)
