@@ -5,7 +5,11 @@ import random
 
 def loadDenseMatrix(filename,log=False):
     #print(filename)
-    data = pd.read_csv(filename, delimiter='\t', index_col=0)
+    try:
+        data = pd.read_csv(filename, delimiter='\t', index_col=0)
+    except:
+        print('Error input matrix, please check https://h1d.readthedocs.io/en/latest/overview.html#input-format')
+        exit(1)
     if log == True:
         return(np.log1p(data))
     else: return data
@@ -22,10 +26,17 @@ def loadWithNorm(filename,method= "RPM",log = False):
 def hic2matrix(path,res,chr,gt):
     if not gt:
         print("rawhic require genome_table file");exit(1)
-    if not isinstance(pd.read_csv(gt,sep="\t",header=None).iloc[0,1],int):
+    try:
+        gtfile = pd.read_csv(gt,sep="\t",header=None)
+        if not isinstance(gtfile.iloc[0,1],int):
+            print("Wrong genome_table file.")
+            print("Please check your genome_table file. Is it tab separated ?")
+            exit(1)
+    except:
         print("Wrong genome_table file.")
-        print("Please use the check your genome_table file. Is it tab separated ?")
+        print("Please check your genome_table file. Is it tab separated ?")
         exit(1)
+
     codepath = os.path.dirname(os.path.realpath(__file__))
     makeIntra = codepath+"/extract/makeMatrixIntra.sh"
     juicer = codepath+"/jc/jctool_1.11.04.jar"
@@ -35,7 +46,8 @@ def hic2matrix(path,res,chr,gt):
     return(matrixpath)
 
 def cool2matrix(path,res,chr,gt):
-    if not gt: print("cool require genome_table file");exit(1)
+    if not gt:
+        print("cool require genome_table file");exit(1)
     codepath = os.path.dirname(os.path.realpath(__file__))
     makeIntra = codepath+"/extract/coolerdump.sh"
     foldername = "./MatrixTemp"+str(random.random())
