@@ -33,7 +33,7 @@ class PlotCommon(object):
         ebin = int(endSite/resolution)
         self.chr = chr
         self.other_parameter = other_parameter
-        self.datatype = datatype
+        self.datatype = "matrix"
 
         if endSite == 0:
             self.matrixRegion = np.nan_to_num(self.matrix.copy())
